# rdpairs
This is a Python package for working with paired-end read data.

<!-- TOC -->

- [rdpairs](#rdpairs)
- [Overview](#overview)
- [Requirements](#requirements)

<!-- /TOC -->

# Overview

rdpairs is a Python package for working with paired-end read data. It provides a set of tools for working with paired-end reads, including:

# Requirements

1. Python 3.10+
2. Python modules:
    - pandas
    - numpy
    - scipy
    - sklearn
    - matplotlib
    - seaborn
    - pysam
3. minimap2
4. samtools
5. bedtools
